==> 1.0.1.tar.gz: SECURITY.md <==
# 1. Security Policies and Procedures

<!-- TOC -->

- [1. Security Policies and Procedures](#1-security-policies-and-procedures)
  - [1.1. Reporting a Bug](#11-reporting-a-bug)
  - [1.2. Disclosure Policy](#12-disclosure-policy)
  - [1.3. Comments on this Policy](#13-comments-on-this-policy)

<!-- /TOC -->

This document outlines security procedures and general policies for the `ThinkIT`
project created by `Kato Shinya`.

## 1.1. Reporting a Bug

The `ThinkIT` team and community take all security bugs in `ThinkIT` seriously.
Thank you for improving the security of `ThinkIT`. We appreciate your efforts and
responsible disclosure and will make every effort to acknowledge your
contributions.

Report security bugs by emailing the lead maintainer at `kato.shinya.dev@gmail.com` or [here](https://github.com/myConsciousness/admob-unit-ids/issues).

The lead maintainer will acknowledge your email within 48 hours, and will send a
more detailed response within 48 hours indicating the next steps in handling
your report. After the initial reply to your report, the security team will
endeavor to keep you informed of the progress towards a fix and full
announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining
the module.

## 1.2. Disclosure Policy

When the security team receives a security bug report, they will assign it to a
primary handler. This person will coordinate the fix and release process,
involving the following steps:

- Confirm the problem and determine the affected versions.
- Audit code to find any potential similar problems.
- Prepare fixes for all releases still under maintenance. These fixes will be
  released as fast as possible.

## 1.3. Comments on this Policy

If you have suggestions on how this process could be improved please submit a
pull request.

==> 1.1.0.tar.gz: SECURITY.md <==
# 1. Security Policies and Procedures

<!-- TOC -->

- [1. Security Policies and Procedures](#1-security-policies-and-procedures)
  - [1.1. Reporting a Bug](#11-reporting-a-bug)
  - [1.2. Disclosure Policy](#12-disclosure-policy)
  - [1.3. Comments on this Policy](#13-comments-on-this-policy)

<!-- /TOC -->

This document outlines security procedures and general policies for the `ThinkIT`
project created by `Kato Shinya`.

## 1.1. Reporting a Bug

The `ThinkIT` team and community take all security bugs in `ThinkIT` seriously.
Thank you for improving the security of `ThinkIT`. We appreciate your efforts and
responsible disclosure and will make every effort to acknowledge your
contributions.

Report security bugs by emailing the lead maintainer at `kato.shinya.dev@gmail.com` or [here](https://github.com/myConsciousness/duolingo4d/issues).

The lead maintainer will acknowledge your email within 48 hours, and will send a
more detailed response within 48 hours indicating the next steps in handling
your report. After the initial reply to your report, the security team will
endeavor to keep you informed of the progress towards a fix and full
announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining
the module.

## 1.2. Disclosure Policy

When the security team receives a security bug report, they will assign it to a
primary handler. This person will coordinate the fix and release process,
involving the following steps:

- Confirm the problem and determine the affected versions.
- Audit code to find any potential similar problems.
- Prepare fixes for all releases still under maintenance. These fixes will be
  released as fast as possible.

## 1.3. Comments on this Policy

If you have suggestions on how this process could be improved please submit a
pull request.
